Method: Qt::Splitter#each

Defined in:
lib/ruber/qt_sugar.rb

#each {|w| ... } ⇒ Qt::Splitter, Enumerator

Iterates on all items in the splitter

The iteration order is from top to bottom and from left to right.

Yields:

  • (w)

    block to call for each widget in the splitter

Yield Parameters:

  • w (Qt::Widget)

    each widget

Returns:

  • (Qt::Splitter, Enumerator)

    if no block is given, returns an enumerator, otherwise returns self



701
702
703
704
705
# File 'lib/ruber/qt_sugar.rb', line 701

def each
  return to_enum unless block_given?
  count.times{|i| yield widget(i)}
  self
end