Method: Ruber::AbstractProject#finalize

Defined in:
lib/ruber/project.rb

#finalizenil

Note:

This method has nothing to do with finalizers

Registers each component with the project

This is done in #initialize because, at least for DocumentProject, the extensions may try to access the project (directly or not) before it has fully been created.

This method should only be called from the object calling new

Returns:

  • (nil)


338
339
340
341
# File 'lib/ruber/project.rb', line 338

def finalize
  Ruber[:components].each_component{|c| c.register_with_project self}
  nil
end