Method: Ruber::ExternalProgramPlugin#shutdown

Defined in:
lib/ruber/external_program_plugin.rb

#shutdownObject

Prepares the plugin to be unloaded by killing the process (no signal will be emitted from the process or the plugin from now on).

If you reimplement this method, don’t forget to call super. If you don’t you might cause a crash when Ruber is closed



172
173
174
175
176
# File 'lib/ruber/external_program_plugin.rb', line 172

def shutdown
  @process.block_signals true
  @process.kill
  super
end