Method: Ruber::NewProjectDialog::NewProjectWidget#project_name

Defined in:
lib/ruber/main_window/main_window_actions.rb

#project_nameString

Returns the name chosen by the user for the project.

Returns:

  • (String)

    the name chosen by the user for the project



830
831
832
# File 'lib/ruber/main_window/main_window_actions.rb', line 830

def project_name
  @ui.project_name.text
end