Method: Ruber::PluginLike#add_widgets_to_project

Defined in:
lib/ruber/plugin_like.rb

#add_widgets_to_project(prj) ⇒ nil

Adds the project widgets provided by the plugin to a project

Only the widgets matching the project will be added.

Parameters:

Returns:

  • (nil)


246
247
248
249
250
251
# File 'lib/ruber/plugin_like.rb', line 246

def add_widgets_to_project prj
  @plugin_description.project_widgets.each do |w| 
    prj.add_widget w if prj.match_rule? w
  end
  nil
end