Method: Ruber::PluginLike#register_with_project

Defined in:
lib/ruber/plugin_like.rb

#register_with_project(prj) ⇒ nil

Informs a project of the existance of the plugin

The base class implemenetation adds all the known project options, poject widgets and project extensions to the project. If a plugin needs to do something fancy with projects, it can override this method and do it from here, after calling the base class implementation.

Parameters:

Returns:

  • (nil)


359
360
361
362
363
# File 'lib/ruber/plugin_like.rb', line 359

def register_with_project prj
  add_options_to_project prj, true
  add_widgets_to_project prj
  add_extensions_to_project prj, true
end