Method: Ruber::PluginLike#remove_from_project

Defined in:
lib/ruber/plugin_like.rb

#remove_from_project(prj) ⇒ nil

Removes all traces of the plugin from a project

This method is called when the plugin is unloaded or when the project is closed and takes care of removeing all project options, project widgets and project extensions belonging to the plugin from the project.

If a plugin needs to do some other cleanup when removed from a project, it can override this method and do what it needs here (usually before calling super)

Parameters:

Returns:

  • (nil)


377
378
379
380
381
# File 'lib/ruber/plugin_like.rb', line 377

def remove_from_project prj
  remove_options_from_project prj, true
  remove_widgets_from_project prj
  remove_extensions_from_project prj, true
end