Method: Ruber::SettingsContainer#dialog

Defined in:
lib/ruber/settings_container.rb

#dialogQt::Dialog

The dialog associated with the container

If a dialog has already been created, it will be returned. Otherwise, another dialog will be created and filled with the widgets added to the container

The dialog will be an instance of the class stored in the @@dialog_class@ instance variable.

Returns:

  • (Qt::Dialog)

    the dialog associated with the container.

See Also:



415
416
417
# File 'lib/ruber/settings_container.rb', line 415

def dialog
  @dialog ||= @dialog_class.new self, @known_options.values, @widgets, @dialog_title
end