Method: Ruber::SettingsContainer#has_setting?

Defined in:
lib/ruber/settings_container.rb

#has_setting?(group, name) ⇒ Boolean Also known as: has_option?

Whether a given setting has been added to the container

Parameters:

  • group (Symbol)

    the name the setting belongs to

  • name (Symbol)

    the name of the setting

Returns:

  • (Boolean)

    true if the setting had already been added and false otherwise



251
252
253
# File 'lib/ruber/settings_container.rb', line 251

def has_setting? group, name
  !@known_options[[group, name]].nil?
end