Method: Ruber::SettingsContainer#relative_path?

Defined in:
lib/ruber/settings_container.rb

#relative_path?(group, name) ⇒ Boolean

Whether a setting should be considered a relative path or not

name has a @relative_path@ method and it returns true and false otherwise

Parameters:

  • group (Sybmol)

    the group the setting belongs to

  • the (String)

    name of the setting

Returns:

  • (Boolean)

    true if the settings object corresponding to group and



354
355
356
# File 'lib/ruber/settings_container.rb', line 354

def relative_path? group, name
  @known_options[[group, name]].relative_path.to_bool rescue false
end