Method: Ruber::SettingsDialogManager#initialize

Defined in:
lib/ruber/settings_dialog_manager.rb

#initialize(dlg, options, widgets) ⇒ SettingsDialogManager

Creates a new SettingsDialogManager. The first argument is the SettingsDialog whose widgets will be managed by the new instance. The second argument is an array with the option objects corresponding to the options which are candidates for automatic management. The keys of the hash are the option objects, which contain all the information about the options, while the values are the values of the options. widgets is a list of widgets where to look for for widgets corresponding to the options.

When the SettingsDialogManager instance is created, associations between options and widgets are created, but the widgets themselves aren’t updated with the values of the options.



274
275
276
277
278
279
280
# File 'lib/ruber/settings_dialog_manager.rb', line 274

def initialize dlg, options, widgets
  super(dlg)
  @widgets = widgets
  @container = dlg.settings_container
  @associations = {}
  options.each{|o| setup_option o}
end