Method: Ruber::SettingsDialogManager#read_default_settings

Defined in:
lib/ruber/settings_dialog_manager.rb

#read_default_settingsObject

It works like read_settings except for the fact that it updates the widgets with the default values of the options.



320
321
322
323
324
325
326
327
328
# File 'lib/ruber/settings_dialog_manager.rb', line 320

def read_default_settings
  @associations.each_pair do |o, data|
    group, name = o[1..-1].split('__').map(&:to_sym)
    value = @container.default(group, name)
    old_value = call_widget_method data
    value = convert_value(value, old_value)
    call_widget_method data, value
  end
end