Method: Ruber::SettingsDialogManager#store_settings

Defined in:
lib/ruber/settings_dialog_manager.rb

#store_settingsObject

Updates all the automatically managed options by calling setting them to the values returned by the associated ‘store’ methods, converted as described in the the documentation for SettingsDialogManager, convert_value and DEFAULT_CONVERSIONS. It emits the settings_changed signal with false as argument.



306
307
308
309
310
311
312
313
314
# File 'lib/ruber/settings_dialog_manager.rb', line 306

def store_settings
  @associations.each_pair do |o, data|
    group, name = o[1..-1].split('__').map(&:to_sym)
    value = call_widget_method(data)
    old_value = @container[group, name]
    value = convert_value value, old_value
    @container[group, name] = value
  end
end