Exception: Ruber::ComponentManager::MissingPlugins

Inherits:
StandardError
  • Object
show all
Defined in:
lib/ruber/component_manager.rb

Overview

Exception raised when some plugins couldn't be found. plugins is an array containing the names of the plugins which couldn't be found, while dirs is an array of the directories searched for those plugins

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(plugins, dirs) ⇒ MissingPlugins

Returns a new instance of MissingPlugins.



394
395
396
397
398
# File 'lib/ruber/component_manager.rb', line 394

def initialize plugins, dirs
  @plugins = plugins.dup
  @dirs = dirs.dup
  super "The plugins #{@plugins.join ' '} couldn't be found in the directories #{@dirs.join ' '}"
end

Instance Attribute Details

#dirsObject (readonly)

Returns the value of attribute dirs.



393
394
395
# File 'lib/ruber/component_manager.rb', line 393

def dirs
  @dirs
end

#pluginsObject (readonly)

Returns the value of attribute plugins.



393
394
395
# File 'lib/ruber/component_manager.rb', line 393

def plugins
  @plugins
end