Class: Ruber::Workspace::StackedWidget

Inherits:
Qt::StackedWidget show all
Defined in:
lib/ruber/main_window/workspace.rb

Overview

Class used by ToolManager to display the currently selected widget. It's a Qt::WidgetStack which handles the keyPressEvent when the key is either Esc or Shift+Esc. In the former case, the tool widget is hidden; in the latter the focus is given back to the editor.

===TODO See whether this can somehow managed using shortcuts

Method Summary

Methods inherited from Qt::StackedWidget

#each, #empty?