Method: Dictionary#order_by_key
- Defined in:
- lib/ruber/utils.rb
#order_by_key ⇒ Object
Works as the method with the same name in facets but works around a bug with facets and ruby 1.9
279 280 281 282 283 |
# File 'lib/ruber/utils.rb', line 279 def order_by_key @order_by = lambda { |i| i[0] } order self end |