Method: Ruber::AbstractProject#each_extension
- Defined in:
- lib/ruber/project.rb
#each_extension ⇒ Object
If called with a block, calls it for each extension passing the extension name and the extension object itself as argument. If called without a block, returns an Enumerator whose each method works as explained above
207 208 209 210 211 212 |
# File 'lib/ruber/project.rb', line 207 def each_extension if block_given? @project_extensions.each_pair{|name, ext| yield name, ext} else self.to_enum(:each_extension) end end |