Method: Ruber::AbstractProject#files
- Defined in:
- lib/ruber/project.rb
#files ⇒ Object
Returns an array containing the name of the files belonging to the project.
This method should be reimplemented in derived classes to return the actual list of files. The base class’s version always returns an empty array.
248 249 250 |
# File 'lib/ruber/project.rb', line 248 def files [] end |