Method: Ruber::Application#status
- Defined in:
- lib/ruber/application/application.rb
#status ⇒ Symbol (readonly)
The state Ruber is in
Ruber can be in three states:
-
starting:= from the time it’s launched to when #setup returns
-
running:= from after #setup has returend to when the user chooses to quit it (either with the @File/Quit@ menu entry or clicking on the button on the title bar)
-
quitting:= from when the user chooses to quit Ruber onwards
-
asking_to_quit:= while asking the user to confirm quitting Ruber
93 94 95 |
# File 'lib/ruber/application/application.rb', line 93 def status @status end |