Method: Ruber::PluginLike#add_widgets_to_project
- Defined in:
- lib/ruber/plugin_like.rb
#add_widgets_to_project(prj) ⇒ nil
Adds the project widgets provided by the plugin to a project
Only the widgets matching the project will be added.
246 247 248 249 250 251 |
# File 'lib/ruber/plugin_like.rb', line 246 def prj @plugin_description..each do |w| prj. w if prj.match_rule? w end nil end |