Method: Ruber::PluginLike#query_close
- Defined in:
- lib/ruber/plugin_like.rb
#query_close ⇒ Boolean
Whether or not the plugin allows the application to shut down
If this method returns false for any plugin, the application won’t be closed.
maybe depending on the status of the plugin itself. As an example, the Document List component checks whether there are unsaved documents and asks the user what to do. If the user decides not to close the appplication, the method will return false.
108 109 110 |
# File 'lib/ruber/plugin_like.rb', line 108 def query_close true end |