Method: Ruber::PluginLike#restore_session
- Defined in:
- lib/ruber/plugin_like.rb
#restore_session(cfg) ⇒ Object
Restores the state of the plugin from session management
This method is called by the component manager when a session needs to be restored. Plugins need to override it if they have some state which needs to be restored (there’s no need to call super when overriding, since the base class method does nothing)
157 158 |
# File 'lib/ruber/plugin_like.rb', line 157 def restore_session cfg end |