Method: Ruber::SettingsContainer#add_widget
- Defined in:
- lib/ruber/settings_container.rb
#add_widget(w) ⇒ nil
Instructs the container to add a widget to the associated dialog
The widget won’t be immediately added to the dialog. This method only gives the container information about the widget to insert in the dialog. The widget itself will only be created and inserted in the dialog when it will first be shown.
This method resets the dialog.
below
383 384 385 386 387 |
# File 'lib/ruber/settings_container.rb', line 383 def w @widgets << w delete_dialog nil end |