Method: Ruber::SettingsContainer#write
- Defined in:
- lib/ruber/settings_container.rb
#write ⇒ nil
Writes the settings to file
If you need to modify the content of an option before writing (for example because it contains a value which can only be read if a specific plugin has been loaded), override this method and change the value of the option, then return the hash.
428 429 430 431 |
# File 'lib/ruber/settings_container.rb', line 428 def write @backend.write nil end |