Method: Ruber::SettingsDialogManager#read_settings
- Defined in:
- lib/ruber/settings_dialog_manager.rb
#read_settings ⇒ Object
Updates all the widgets corresponding to an automatically managed option by calling the associated reader methods, passing them the value read from the option container, converted as described in the the documentation for SettingsDialogManager, convert_value and DEFAULT_CONVERSIONS. It emits the settings_changed signal with true as argument.
289 290 291 292 293 294 295 296 297 |
# File 'lib/ruber/settings_dialog_manager.rb', line 289 def read_settings @associations.each_pair do |o, data| group, name = o[1..-1].split('__').map(&:to_sym) value = @container.relative_path?(group, name) ? @container[group, name, :abs] : @container[group, name] old_value = data value = convert_value(value, old_value) data, value end end |